@@ -81,6 +81,13 @@ testIndFisher = function(target, dataset, xIndex, csIndex, dataInfo=NULL, univar
   x = dataset[ , xIndex];
   cs = dataset[ , csIndex];
   
+  #remove equal columns of the CS
+  if(length(csIndex) > 1)
+  {
+    #remove same columns
+    cs = unique(as.matrix(cs), MARGIN = 2);
+  }
+  
   #checking the length
   if (length(x) == 0 || length(target) == 0)
   {
@@ -89,6 +96,39 @@ testIndFisher = function(target, dataset, xIndex, csIndex, dataInfo=NULL, univar
     return(results);
   }
   
+  #if x = any of the cs then pvalue = 1 and flag = 1.
+  #That means that the x variable does not add more information to our model due to an exact copy of this in the cs, so it is independent from the target
+  if(length(cs)!=0)
+  {
+    if(is.null(dim(cs)[2]) == TRUE) #cs is a vector
+    {
+      if(any(x != cs) == FALSE)  #if(!any(x == cs) == FALSE)
+      {
+        if(hash == TRUE)#update hash objects
+        {
+          .set(stat_hash , key , 0)
+          .set(pvalue_hash , key , 1)
+        }
+        results <- list(pvalue = 1, stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+        return(results);
+      }
+    }else{ #more than one var
+      for(col in 1:dim(cs)[2])
+      {
+        if(any(x != cs[,col]) == FALSE)  #if(!any(x == cs) == FALSE)
+        {
+          if(hash == TRUE)#update hash objects
+          {
+            .set(stat_hash , key , 0)
+            .set(pvalue_hash , key , 1)
+          }
+          results <- list(pvalue = 1, stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+          return(results);
+        }
+      }
+    }
+  }
+  
   #if x or target is constant then there is no point to perform the test
   if(var(x) == 0 || var(target) == 0)
   {
@@ -131,7 +171,7 @@ testIndFisher = function(target, dataset, xIndex, csIndex, dataInfo=NULL, univar
     xyIdx = 1:2;
     csIdx = 3:(ncol(as.matrix(cs))+2); #or csIdx = 3;
     
-    residCorrMatrix = (corrMatrix[xyIdx, xyIdx]) - as.matrix(corrMatrix[xyIdx, csIdx])%*%(solve( as.matrix(corrMatrix[csIdx, csIdx]) , rbind(corrMatrix[csIdx, xyIdx]) ));
+    residCorrMatrix = (corrMatrix[xyIdx, xyIdx]) - as.matrix(corrMatrix[xyIdx, csIdx])%*%(solve( as.matrix(corrMatrix[csIdx, csIdx]) , rbind(corrMatrix[csIdx, xyIdx])));
     #residCorrMatrix = (corrMatrix[xyIdx, xyIdx]) - as.matrix(corrMatrix[xyIdx, csIdx])%*%(mldivide(as.matrix(corrMatrix[csIdx, csIdx]),rbind(corrMatrix[csIdx, xyIdx]) ));
     
     stat = abs(residCorrMatrix[1,2] / sqrt(residCorrMatrix[1,1] * residCorrMatrix[2,2]));
@@ -175,7 +215,7 @@ error=function(cond) {
   message(paste("error in try catch of the testIndFisher test"))
   message("Here's the original error message:")
   message(cond)
-  stop();
+  
   #        
   #        #for debug
   #        printf("\nxIndex = \n");
@@ -183,6 +223,8 @@ error=function(cond) {
   #        printf("\ncsindex = \n");
   #        print(csIndex);
   
+  stop();
+  
   #error case
   pvalue = 1;
   stat = 0;
